==> kadu-0.12.2.tar.bz2: kadu-0.12.2/plugins/config_wizard/translations/config_wizard_cs.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="cs" version="2.0">
<context>
    <name>@default</name>
    <message>
        <source>Kadu needs to be restarted before changes to the language settings will take effect.</source>
        <translation>Kadu je potřeba spustit znovu, aby se změna v nastavení jazyka mohla projevit.</translation>
    </message>
</context>
<context>
    <name>ConfigWizardChooseNetworkPage</name>
    <message>
        <source>&lt;h3&gt;Account Setup&lt;/h3&gt;</source>
        <translation>&lt;h3&gt;Nastavení účtu&lt;/h3&gt;</translation>
    </message>
    <message>
        <source>IM Network</source>
        <translation>Síť IM</translation>
    </message>
    <message>
        <source>I want to set up existing account for Kadu</source>
        <translation>Chci nastavit stávající účet pro Kadu</translation>
    </message>
    <message>
        <source>I want to create new account for Kadu</source>
        <translation>Chci vytvořit nový účet pro Kadu</translation>
    </message>
    <message>
        <source>I don&apos;t want to set up my account for Kadu now</source>
        <translation>Nyní svůj účet pro Kadu nastavit nechci</translation>
    </message>
    <message>
        <source>&lt;p&gt;Please choose the network for the account that you would like to set up.&lt;/p&gt;&lt;p&gt;You can also create a new account in the wizard if you don&apos;t already have one&lt;/p&gt;</source>
        <translation>&lt;p&gt;Vyberte, prosím, síť pro účet, který chcete zřídit.&lt;/p&gt;&lt;p&gt;Také můžete s pomocí průvodce vytvořit nový účet, pokud ještě žádný nemáte&lt;/p&gt;</translation>
    </message>
</context>
<context>
    <name>ConfigWizardCompletedPage</name>
    <message>
        <source>&lt;h3&gt;Configuration Wizard Completed&lt;/h3&gt;</source>
        <translation>&lt;h3&gt;Pprůvodce nastavením dokončen&lt;/h3&gt;</translation>
    </message>
    <message>
        <source>Go to Accounts Setting after closing this window</source>
        <translation>Po zavření tohoto okna jděte do nastavení účtů</translation>
    </message>
    <message>
        <source>&lt;p&gt;Confirm your wizard setting to start using Kadu.&lt;/p&gt;</source>
        <translation>&lt;p&gt;Potvrďte svá nastavení v průvodci, abyste mohli začít používat Kadu.&lt;/p&gt;</translation>
    </message>
</context>
<context>
    <name>ConfigWizardConfigurationUiHandler</name>
    <message>
        <source>Start Configuration Wizard...</source>
        <translation>Spustit průvodce nastavením...</translation>
    </message>
</context>
<context>
    <name>ConfigWizardProfilePage</name>
    <message>
        <source>&lt;h3&gt;Welcome to Kadu Instant Messenger&lt;/h3&gt;&lt;p&gt;This wizard will help you to configure the basic settings of Kadu.&lt;/p&gt;&lt;p&gt;Please choose a preferred language and create a nickname&lt;/p&gt;</source>
        <translation>&lt;h3&gt;Vítejte v Kadu, programu pro okamžitou výměnu zpráv&lt;/h3&gt;&lt;p&gt;Tento průvodce vám pomůže s nastavením základních nastavení Kadu.&lt;/p&gt;&lt;p&gt;Zvolte, prosím, upřednostňovaný jazyk a vytvořte si přezdívku&lt;/p&gt;</translation>
    </message>
    <message>
        <source>&lt;h3&gt;Profile setup&lt;/h3&gt;</source>
        <translation>&lt;h3&gt;Nastavení profilu&lt;/h3&gt;</translation>
    </message>
    <message>
        <source>Language</source>
        <translation>Jazyk</translation>
    </message>
    <message>
        <source>Nickname</source>
        <translation>Přezdívka</translation>
    </message>
</context>
<context>
    <name>ConfigWizardSetUpAccountPage</name>
    <message>
        <source>&lt;h3&gt;Account Setup&lt;/h3&gt;</source>
        <translation>&lt;h3&gt;Nastavení účtu&lt;/h3&gt;</translation>
    </message>
    <message>
        <source>&lt;p&gt;Please enter your account data.&lt;/p&gt;&lt;p&gt;Go back if you want to select a different Account Setup option.&lt;/p&gt;</source>
        <translation>&lt;p&gt;Zadejte, prosím, údaje ke svému účtu.&lt;/p&gt;&lt;p&gt;Jděte zpět, pokud chcete vybrat jinou volbu pro vytvoření účtu.&lt;/p&gt;</translation>
    </message>
</context>
<context>
    <name>ConfigWizardWindow</name>
    <message>
        <source>Kadu Wizard</source>
        <translation>Průvodce pro Kadu</translation>
    </message>
</context>
</TS>

==> kadu_1.1.orig.tar.bz2: kadu-1.1/plugins/config_wizard/translations/config_wizard_cs.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="cs" version="2.0">
<context>
    <name>@default</name>
    <message>
        <source>Kadu needs to be restarted before changes to the language settings will take effect.</source>
        <translation>Kadu je potřeba spustit znovu, aby se změna v nastavení jazyka mohla projevit.</translation>
    </message>
</context>
<context>
    <name>ConfigWizardChooseNetworkPage</name>
    <message>
        <source>&lt;h3&gt;Account Setup&lt;/h3&gt;</source>
        <translation>&lt;h3&gt;Nastavení účtu&lt;/h3&gt;</translation>
    </message>
    <message>
        <source>IM Network</source>
        <translation>Síť IM</translation>
    </message>
    <message>
        <source>I want to set up existing account for Kadu</source>
        <translation>Chci nastavit stávající účet pro Kadu</translation>
    </message>
    <message>
        <source>I want to create new account for Kadu</source>
        <translation>Chci vytvořit nový účet pro Kadu</translation>
    </message>
    <message>
        <source>I don&apos;t want to set up my account for Kadu now</source>
        <translation>Nyní svůj účet pro Kadu nastavit nechci</translation>
    </message>
    <message>
        <source>&lt;p&gt;Please choose the network for the account that you would like to set up.&lt;/p&gt;&lt;p&gt;You can also create a new account in the wizard if you don&apos;t already have one&lt;/p&gt;</source>
        <translation>&lt;p&gt;Vyberte, prosím, síť pro účet, který chcete zřídit.&lt;/p&gt;&lt;p&gt;Také můžete s pomocí průvodce vytvořit nový účet, pokud ještě žádný nemáte&lt;/p&gt;</translation>
    </message>
</context>
<context>
    <name>ConfigWizardCompletedPage</name>
    <message>
        <source>&lt;h3&gt;Configuration Wizard Completed&lt;/h3&gt;</source>
        <translation>&lt;h3&gt;Průvodce nastavením dokončen&lt;/h3&gt;</translation>
    </message>
    <message>
        <source>Go to Accounts Setting after closing this window</source>
        <translation>Po zavření tohoto okna jděte do nastavení účtů</translation>
    </message>
    <message>
        <source>&lt;p&gt;Confirm your wizard setting to start using Kadu.&lt;/p&gt;</source>
        <translation>&lt;p&gt;Potvrďte svá nastavení v průvodci, abyste mohli začít používat Kadu.&lt;/p&gt;</translation>
    </message>
</context>
<context>
    <name>ConfigWizardConfigurationUiHandler</name>
    <message>
        <source>Start Configuration Wizard</source>
        <translation>Spustit průvodce nastavením</translation>
    </message>
</context>
<context>
    <name>ConfigWizardProfilePage</name>
    <message>
        <source>&lt;h3&gt;Welcome to Kadu Instant Messenger&lt;/h3&gt;&lt;p&gt;This wizard will help you to configure the basic settings of Kadu.&lt;/p&gt;&lt;p&gt;Please choose a preferred language and create a nickname&lt;/p&gt;</source>
        <translation>&lt;h3&gt;Vítejte v Kadu, programu pro okamžitou výměnu zpráv&lt;/h3&gt;&lt;p&gt;Tento průvodce vám pomůže s nastavením základních nastavení Kadu.&lt;/p&gt;&lt;p&gt;Zvolte, prosím, upřednostňovaný jazyk a vytvořte si přezdívku&lt;/p&gt;</translation>
    </message>
    <message>
        <source>&lt;h3&gt;Profile setup&lt;/h3&gt;</source>
        <translation>&lt;h3&gt;Nastavení profilu&lt;/h3&gt;</translation>
    </message>
    <message>
        <source>Language</source>
        <translation>Jazyk</translation>
    </message>
    <message>
        <source>Nickname</source>
        <translation>Přezdívka</translation>
    </message>
</context>
<context>
    <name>ConfigWizardSetUpAccountPage</name>
    <message>
        <source>&lt;h3&gt;Account Setup&lt;/h3&gt;</source>
        <translation>&lt;h3&gt;Nastavení účtu&lt;/h3&gt;</translation>
    </message>
    <message>
        <source>&lt;p&gt;Please enter your account data.&lt;/p&gt;&lt;p&gt;Go back if you want to select a different Account Setup option.&lt;/p&gt;</source>
        <translation>&lt;p&gt;Zadejte, prosím, údaje ke svému účtu.&lt;/p&gt;&lt;p&gt;Jděte zpět, pokud chcete vybrat jinou volbu pro vytvoření účtu.&lt;/p&gt;</translation>
    </message>
</context>
<context>
    <name>ConfigWizardWindow</name>
    <message>
        <source>Kadu Wizard</source>
        <translation>Průvodce pro Kadu</translation>
    </message>
</context>
</TS>
